==> mongodb-src-r3.0.5.tar.gz: mongodb-src-r3.0.5/src/mongo/util/moveablebuffer.h <==
/* moveablebuffer.h
*/

/*    Copyright 2009 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#pragma once

namespace mongo {

    /** this is a sort of smart pointer class where we can move where something is and all the pointers will adjust.
        not threadsafe.
        */
    struct MoveableBuffer {
        MoveableBuffer();
        MoveableBuffer(void *);
        MoveableBuffer& operator=(const MoveableBuffer&);
        ~MoveableBuffer();

        void *p;
    };

    /* implementation (inlines) below */

    // this is a temp stub implementation...not really done yet - just having everything compile & such for checkpointing into git

    inline MoveableBuffer::MoveableBuffer() : p(0) { }

    inline MoveableBuffer::MoveableBuffer(void *_p) : p(_p) { }

    inline MoveableBuffer& MoveableBuffer::operator=(const MoveableBuffer& r) {
        p = r.p;
        return *this;
    }

    inline MoveableBuffer::~MoveableBuffer() {
    }

}

==> mongodb-src-r3.0.14.tar.gz: mongodb-src-r3.0.14/src/mongo/util/moveablebuffer.h <==
/* moveablebuffer.h
*/

/*    Copyright 2009 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#pragma once

namespace mongo {

/** this is a sort of smart pointer class where we can move where something is and all the pointers
 * will adjust.
    not threadsafe.
    */
struct MoveableBuffer {
    MoveableBuffer();
    MoveableBuffer(void*);
    MoveableBuffer& operator=(const MoveableBuffer&);
    ~MoveableBuffer();

    void* p;
};

/* implementation (inlines) below */

// this is a temp stub implementation...not really done yet - just having everything compile & such
// for checkpointing into git

inline MoveableBuffer::MoveableBuffer() : p(0) {}

inline MoveableBuffer::MoveableBuffer(void* _p) : p(_p) {}

inline MoveableBuffer& MoveableBuffer::operator=(const MoveableBuffer& r) {
    p = r.p;
    return *this;
}

inline MoveableBuffer::~MoveableBuffer() {}
}
